==> ark-19.04.3.tar.xz: ark-19.04.3/app/ark_dndextract.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=KIO/DndPopupMenu/Plugin
X-KDE-Library=extracthere
Name=Ark Extract Here
Name[ar]=أرك استخرج هنا
Name[bg]=Извличане тук
Name[bs]=Raspakuj Arkom ovde
Name[ca]=Extracció de l'Ark aquí
Name[ca@valencia]=Extracció de l'Ark ací
Name[cs]=Rozbalit Arkem sem
Name[da]=Pak ud med Ark her
Name[de]=Ark – Hierher entpacken
Name[el]=Εξαγωγή Ark εδώ
Name[en_GB]=Ark Extract Here
Name[es]=Extraer aquí con Ark
Name[et]=Paki siia lahti
Name[eu]=Ark: Erauzi hemen
Name[fi]=Ark – Pura tähän
Name[fr]=Extraire un fichier « Ark » ici
Name[ga]=Bain an chartlann Ark amach agus cuir é anseo
Name[gl]=Extraer aquí con Ark
Name[he]=חלץ בעזרת ארק לכאן
Name[hr]=Ovdje Ark-otpakiraj
Name[hu]=Kibontás ide
Name[ia]=Ark Extrahe hic
Name[id]=Ark Ekstrak di Sini
Name[is]=Ark afþjappa hingað
Name[it]=Ark Estrai qui
Name[ja]=Ark ここに展開
Name[kk]=Мынаған тарқату
Name[km]=ស្រង់ចេញ Ark នៅ​ទីនេះ
Name[ko]=Ark 여기에 풀기
Name[lt]=Išpakuoti čia su Ark
Name[lv]=Ark atspiest šeit
Name[mr]=येथे आर्क पुर्ववत करा
Name[nb]=Pakk ut arkivet her med Ark
Name[nds]=Hier mit Ark utpacken
Name[nl]=Ark: hier uitpakken
Name[nn]=Pakk ut med Ark her
Name[pa]=ਅਕਾਇਵ ਇੱਥੇ ਖੋਲ੍ਹੋ
Name[pl]=Wypakuj tutaj
Name[pt]=Extrair para Aqui
Name[pt_BR]=Extrair com o Ark aqui
Name[ro]=Ark extrage aici
Name[ru]=Распаковать в эту папку
Name[sk]=Ark - rozbaliť sem
Name[sl]=Razširi sem z Arkom
Name[sq]=Ark Ekstrakton Këtu
Name[sr]=Распакуј Арком овде
Name[sr@ijekavian]=Распакуј Арком овдје
Name[sr@ijekavianlatin]=Raspakuj Arkom ovdje
Name[sr@latin]=Raspakuj Arkom ovde
Name[sv]=Packa upp arkiv här
Name[th]=อาร์ก คลายแฟ้มไว้ที่นี่
Name[tr]=Ark Arşivi Buraya Çıkart
Name[uk]=Видобути архів сюди з Ark
Name[wa]=Saetchî foû avou Ark cial
Name[x-test]=xxArk Extract Herexx
Name[zh_CN]=Ark 在此解压缩
Name[zh_TW]=在此解壓縮
MimeType=@SUPPORTED_ARK_MIMETYPES@

==> ark-19.11.90.tar.xz: ark-19.11.90/app/ark_dndextract.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=KIO/DndPopupMenu/Plugin
X-KDE-Library=extracthere
Name=Ark Extract Here
Name[ar]=أرك استخرج هنا
Name[bg]=Извличане тук
Name[bs]=Raspakuj Arkom ovde
Name[ca]=Extracció de l'Ark aquí
Name[ca@valencia]=Extracció de l'Ark ací
Name[cs]=Rozbalit Arkem sem
Name[da]=Pak ud med Ark her
Name[de]=Ark – Hierher entpacken
Name[el]=Εξαγωγή Ark εδώ
Name[en_GB]=Ark Extract Here
Name[es]=Extraer aquí con Ark
Name[et]=Paki siia lahti
Name[eu]=Ark: Erauzi hemen
Name[fi]=Ark – Pura tähän
Name[fr]=Extraire un fichier « Ark » ici
Name[ga]=Bain an chartlann Ark amach agus cuir é anseo
Name[gl]=Extraer aquí con Ark
Name[he]=חלץ בעזרת ארק לכאן
Name[hr]=Ovdje Ark-otpakiraj
Name[hu]=Kibontás ide
Name[ia]=Ark Extrahe hic
Name[id]=Ark Ekstrak di Sini
Name[is]=Ark afþjappa hingað
Name[it]=Ark Estrai qui
Name[ja]=Ark ここに展開
Name[kk]=Мынаған тарқату
Name[km]=ស្រង់ចេញ Ark នៅ​ទីនេះ
Name[ko]=Ark 여기에 풀기
Name[lt]=Išpakuoti čia naudojant Ark
Name[lv]=Ark atspiest šeit
Name[mr]=येथे आर्क पुर्ववत करा
Name[nb]=Pakk ut arkivet her med Ark
Name[nds]=Hier mit Ark utpacken
Name[nl]=Ark: hier uitpakken
Name[nn]=Pakk ut med Ark her
Name[pa]=ਅਕਾਇਵ ਇੱਥੇ ਖੋਲ੍ਹੋ
Name[pl]=Wypakuj tutaj
Name[pt]=Extrair para Aqui
Name[pt_BR]=Extrair com o Ark aqui
Name[ro]=Ark extrage aici
Name[ru]=Распаковать в эту папку
Name[sk]=Ark - rozbaliť sem
Name[sl]=Razširi sem z Arkom
Name[sq]=Ark Ekstrakton Këtu
Name[sr]=Распакуј Арком овде
Name[sr@ijekavian]=Распакуј Арком овдје
Name[sr@ijekavianlatin]=Raspakuj Arkom ovdje
Name[sr@latin]=Raspakuj Arkom ovde
Name[sv]=Packa upp arkiv här
Name[th]=อาร์ก คลายแฟ้มไว้ที่นี่
Name[tr]=Ark Arşivi Buraya Çıkart
Name[uk]=Видобути архів сюди з Ark
Name[wa]=Saetchî foû avou Ark cial
Name[x-test]=xxArk Extract Herexx
Name[zh_CN]=Ark 在此解压缩
Name[zh_TW]=在此解壓縮
MimeType=@SUPPORTED_ARK_MIMETYPES@
